Error struct and enum for the different error messages the app shows
Structs
- Error
- The Struct containing the ErrorKind enum
Enums
- Error
Kind - The ErrorKind enum that states all possible errors that can happen in the application and error messagges that are shown to the user in case those happen
Type Aliases
- Result
- Generic
Result<T>type for the application